"""High level API for email."""
from typing import Any, Dict, List, Optional
from uuid import UUID

from .message import Message, MessageEnvelope


class Email(Message):
    """Provide a structure for Email message."""

    recipient: str
    subject_template: str
    body_template: str
    body_template_html: Optional[str] = None
    subject_template_uuid: Optional[UUID] = None
    body_template_uuid: Optional[UUID] = None
    body_template_html_uuid: Optional[UUID] = None
    sender: Optional[str] = None
    extra_headers: Dict[str, str] = {}
    context: Dict[str, Any] = {}
    attachments: List[str] = []

    render_fields = ("subject", "body", "body_html")

    @property
    def subject(self) -> str:
        """Render subject using django-secretary."""
        return self._secretary_render(
            "subject", template=self.subject_template_uuid or self.subject_template
        )

    @property
    def body(self) -> str:
        """Render body using django-secretary."""
        return self._secretary_render(
            "body", template=self.body_template_uuid or self.body_template
        )

    @property
    def body_html(self) -> Optional[str]:
        """Render body_html using django-secretary."""
        template = self.body_template_html_uuid or self.body_template_html
        if template:
            return self._secretary_render(
                "body_html",
                template=template,
                render_method_name="render_html",
            )
        else:
            return None


class EmailEnvelope(MessageEnvelope[Email]):
    """Provide a structure for Email envelope."""

    message_id: Optional[str] = None
